# BestPix

Use your Mac to see the photos your iPhone thinks are best.

## Description 

Each time you take a photo with your iPhone, a "beautifulness" score is given to that photo. This package shows you the 10 highest scoring photos.

## Privacy

This package does not upload any data. 


##  Setup
1. Import your iPhone's photos to your Mac, official instructions [here](https://support.apple.com/en-us/HT201302#importmac)
2. Open your terminal:
   1. To install, run `pip3 install bestpix`
   2. To start, run `reveal`
3. To see the best pictures, go to `localhost:8442` in your browser